@@ -1,4 +1,4 @@
-# Copyright 2001-2017, Paul Johnson (paul@pjcj.net)
+# Copyright 2001-2019, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -12,7 +12,7 @@ use warnings;
 
 our $VERSION;
 BEGIN {
-our $VERSION = '1.30'; # VERSION
+our $VERSION = '1.32'; # VERSION
 }
 
 use DynaLoader ();
@@ -777,18 +777,18 @@ sub _report {
 
     unless ($Subs_only) {
         get_cover(main_cv, main_root);
-        get_cover($_)
-            for B::begin_av()->isa("B::AV") ? B::begin_av()->ARRAY : ();
+        get_cover_progress("BEGIN block",
+            B::begin_av()->isa("B::AV") ? B::begin_av()->ARRAY : ());
         if (exists &B::check_av) {
-            get_cover($_)
-                for B::check_av()->isa("B::AV") ? B::check_av()->ARRAY : ();
+            get_cover_progress("CHECK block",
+                B::check_av()->isa("B::AV") ? B::check_av()->ARRAY : ());
         }
         # get_ends includes INIT blocks
-        get_cover($_)
-            for get_ends()->isa("B::AV") ? get_ends()->ARRAY : ();
+        get_cover_progress("END/INIT block",
+            get_ends()->isa("B::AV") ? get_ends()->ARRAY : ());
     }
     # print STDERR "--- @Cvs\n";
-    get_cover($_) for @Cvs;
+    get_cover_progress("CV", @Cvs);
 
     my %files;
     $files{$_}++ for keys %{$Run{count}}, keys %{$Run{vec}};
@@ -1025,6 +1025,11 @@ sub deparse {
             # Collect everything under here
             local ($File, $Line) = ($File, $Line);
             # print STDERR "Collecting $$op under $File:$Line\n";
+            no warnings "redefine";
+            my $use_dumper = $class eq 'SVOP' && $name eq 'const';
+            local *B::Deparse::const = \&B::Deparse::const_dumper
+              if $use_dumper;
+            require Data::Dumper if $use_dumper;
             $deparse = eval { local $^W; $Original{deparse}->($self, @_) };
             $deparse =~ s/^\010+//mg if defined $deparse;
             $deparse = "Deparse error: $@" if $@;
@@ -1271,6 +1276,34 @@ sub get_cover {
     $de
 }
 
+sub _report_progress {
+    my ($msg, $code, @items) = @_;
+    if ($Silent) {
+        $code->($_) for @items;
+        return;
+    }
+    my $tot = @items || 1;
+    my $prog = sub {
+        my ($n) = @_;
+        print OUT "\r" . __PACKAGE__ . ": " . int(100 * $n / $tot) . "% ";
+    };
+    my ($old_pipe, $n, $start) = ($|, 0, time);
+    $|++;
+    print OUT __PACKAGE__, ": $msg\n";
+    for (@items) {
+        $prog->($n++);
+        $code->($_);
+    }
+    $prog->($n || 1);
+    print OUT "- " . (time - $start) . "s taken\n";
+    $| = $old_pipe;
+}
+
+sub get_cover_progress {
+    my ($type, @cvs) = @_;
+    _report_progress("getting $type coverage", sub { get_cover($_) }, @cvs);
+}
+
 "
 We have normality, I repeat we have normality.
 Anything you still can’t cope with is therefore your own problem.
@@ -1284,7 +1317,7 @@ Devel::Cover - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.30
+version 1.32
 
 =head1 SYNOPSIS
 
@@ -1464,7 +1497,7 @@ In this example, Devel::Cover will be operating in silent mode.
                        "/Devel/Cover\b")
  +ignore RE          - Append to regular expressions of files to ignore
  -inc path           - Set prefixes of files to include (default @INC)
- +inc path           - Append to prefixes of files regular expressionsto include
+ +inc path           - Append to prefixes of files to include
  -loose_perms val    - Use loose permissions on all files and directories in
                        the coverage db so that code changing EUID can still
                        write coverage information (default off)
@@ -1603,14 +1636,14 @@ If there is an elsif in the branch then it can be addressed as the second
 branch on the line by using the "count" attribute.  Further elsifs are the
 third and fourth "count" value, and so on:
 
-# uncoverable branch false count:2
-if ($thing == 1) {
-    handle_thing_being_one();
-} elsif ($thing == 2) {
-    handle_thing_being_tow();
-} else {
-    die "thing can only be one or two, not $thing"; # uncoverable statement
-}
+    # uncoverable branch false count:2
+    if ($thing == 1) {
+        handle_thing_being_one();
+    } elsif ($thing == 2) {
+        handle_thing_being_tow();
+    } else {
+        die "thing can only be one or two, not $thing"; # uncoverable statement
+    }
 
 =head3 Conditions
 
@@ -1803,7 +1836,7 @@ Please report new bugs on Github.
 
 =head1 LICENCE
 
-Copyright 2001-2017, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2019, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
