@@ -1,4 +1,4 @@
-# Copyright 2014-2017, Paul Johnson (paul@pjcj.net)
+# Copyright 2014-2019, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,7 +10,7 @@ package Devel::Cover::Collection;
 use 5.26.0;
 use warnings;
 
-our $VERSION = '1.30'; # VERSION
+our $VERSION = '1.32'; # VERSION
 
 use Devel::Cover::DB;
 use Devel::Cover::DB::IO::JSON;
@@ -210,7 +210,8 @@ sub run {
     $output .= "Testing $module in $build_dir\n";
     # say "\n$line\n$output$line\n"; return;
 
-    # $self->sys($^X, "-V");
+    # $output .= $self->sys($^X, "-V");
+    # $output .= $self->sys("pwd");
     my @cmd;
     if ($self->local) {
         $ENV{DEVEL_COVER_OPTIONS} = "-ignore,/usr/local/lib/perl5";
@@ -220,9 +221,9 @@ sub run {
         @cmd = ($^X, $self->bin_dir . "/cover");
     }
     $output .= $self->fbsys(
-        @cmd,          "-test",
-        "-report",     $self->report,
-        "-outputfile", $self->output_file,
+        @cmd,           "--test",
+        "--report",     $self->report,
+        "--outputfile", $self->output_file,
     );
     $output .= $self->fsys(@cmd, "-report", "json", "-nosummary");
 
@@ -559,7 +560,7 @@ sub cover_modules {
             eval {
                 local $SIG{ALRM} = sub { die "alarm\n" };
                 alarm $timeout;
-                say "running: @command" if $self->verbose;
+                say "running: @command $module $name" if $self->verbose;
                 system @command, $module, $name;
                 alarm 0;
             };
@@ -593,12 +594,12 @@ sub get_latest {
 
     while (my $release = $iterator->next_release) {
         say $release->path;
-        next;
-        printf "%s path=%s  time=%d  size=%d\n",
-               $release->distname,
-               $release->path,
-               $release->timestamp,
-               $release->size;
+        # Debugging code:
+        # printf "%s path=%s  time=%d  size=%d\n",
+               # $release->distname,
+               # $release->path,
+               # $release->timestamp,
+               # $release->size;
     }
 }
 
@@ -702,7 +703,7 @@ package Devel::Cover::Collection::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = '1.30'; # VERSION
+our $VERSION = '1.32'; # VERSION
 
 use base "Template::Provider";
 
@@ -739,7 +740,7 @@ $Templates{html} = <<'EOT';
 <html xmlns="http://www.w3.org/1999/xhtml">
 <!--
 This file was generated by Devel::Cover Version $VERSION
-Devel::Cover is copyright 2001-2017, Paul Johnson (paul\@pjcj.net)
+Devel::Cover is copyright 2001-2019, Paul Johnson (paul\@pjcj.net)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
 http://www.pjcj.net
@@ -883,7 +884,7 @@ Devel::Cover::Collection - Code coverage for a collection of modules
 
 =head1 VERSION
 
-version 1.30
+version 1.32
 
 =head1 SYNOPSIS
 
@@ -899,7 +900,7 @@ Almost certainly.
 
 =head1 LICENCE
 
-Copyright 2014-2017, Paul Johnson (paul@pjcj.net)
+Copyright 2014-2019, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
