@@ -1,4 +1,4 @@
-# Copyright 2002-2017, Paul Johnson (paul@pjcj.net)
+# Copyright 2002-2019, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,7 +10,7 @@ package Devel::Cover::Test;
 use strict;
 use warnings;
 
-our $VERSION = '1.28'; # VERSION
+our $VERSION = '1.32'; # VERSION
 
 use Carp;
 
@@ -19,6 +19,28 @@ use Test::More;
 
 use Devel::Cover::Inc;
 
+my $LATEST_RELEASED_PERL = 28;
+my %TEST2VERSIONOVERRIDE = (
+    bigint => \&_default_version_override,
+);
+my %TEST2MODULE2VERSION2PERL = (
+    bigint => { 'Math::BigInt' => { '1.999806' => '5.026000' } },
+);
+sub _default_version_override {
+    my ($test, $v) = @_;
+    return $v unless my $override = $TEST2MODULE2VERSION2PERL{$test};
+    my @perl_versions = $v;
+    for my $module (sort keys %$override) {
+        my $version2perl = $override->{$module};
+        eval "require $module"; # string-eval saves faff with turning to file
+        die $@ if $@;
+        my $modversion = do { no strict 'refs'; ${$module . '::VERSION'} };
+        push @perl_versions, map $version2perl->{$_},
+            grep $_ < $modversion, keys %$version2perl;
+    }
+    return (sort @perl_versions)[-1]; # highest version found
+}
+
 sub new {
     my $class = shift;
     my $test  = shift;
@@ -145,30 +167,31 @@ sub test_file_parameters {
     exists $self->{test_file_parameters} ? $self->{test_file_parameters} : ""
 }
 
-sub cover_gold {
-    my $self = shift;
-
-    my $test = $self->{golden_test} || $self->{test};
-
-    my $td = "./test_output/cover";
+sub _get_right_version {
+    my ($td, $test) = @_;
     opendir D, $td or die "Can't opendir $td: $!";
     my @versions = sort    { $a <=> $b }
                    map     { /^$test\.(5\.\d+)$/ ? $1 : () }
                    readdir D;
     closedir D or die "Can't closedir $td: $!";
     # print STDERR "Versions for [$test] from [$td] @versions\n";
-
     my $v = "5.0";
     for (@versions) {
         last if $_ > $];
         $v = $_;
     }
-
     # die "Can't find golden results for $test" if $v eq "5.0";
+    return $v unless my $override_sub = $TEST2VERSIONOVERRIDE{$test};
+    $override_sub->($test, $v);
+}
 
-    $v = $ENV{DEVEL_COVER_GOLDEN_VERSION}
-        if exists $ENV{DEVEL_COVER_GOLDEN_VERSION};
-
+sub cover_gold {
+    my $self = shift;
+    my $td = "./test_output/cover";
+    my $test = $self->{golden_test} || $self->{test};
+    my $v = exists $ENV{DEVEL_COVER_GOLDEN_VERSION}
+        ? $ENV{DEVEL_COVER_GOLDEN_VERSION}
+        : _get_right_version($td, $test);
     ("$td/$test", $v eq "5.0" ? 0 : $v)
 }
 
@@ -195,6 +218,8 @@ sub run_command {
 sub run_test {
     my $self = shift;
 
+    $ENV{DEVEL_COVER_TEST_SUITE} = 1;
+
     if ($] < 5.010000) {
         plan skip_all => "Perl version $] is not supported";
         return;
@@ -206,7 +231,7 @@ sub run_test {
     }
 
     my $version = int(($] - 5) * 1000 + 0.5);
-    if ($version % 2 && $version < 26) {
+    if ($version % 2 && $version < $LATEST_RELEASED_PERL) {
         plan skip_all => "Perl version $] is an obsolete development version";
         return;
     }
@@ -303,7 +328,7 @@ sub run_cover {
     if ($self->{differences}) {
         no warnings "redefine";
         local *Test::_quote = sub { "@_" };
-        $self->{no_coverage} ? pass : eq_or_diff(\@at, \@ac, "output");
+        $self->{no_coverage} ? pass : eq_or_diff(\@at, \@ac, "output", { context => 0 });
     } elsif ($self->{no_coverage}) {
         pass for @{$self->{cover}};
     }
@@ -390,7 +415,7 @@ Devel::Cover::Test - Internal module for testing
 
 =head1 VERSION
 
-version 1.28
+version 1.32
 
 =head1 METHODS
 
@@ -477,6 +502,10 @@ version number.
 $base comes from the name of the test and $v will be $] from the earliest perl
 version for which the golden results should be the same as for the current $]
 
+C<$v> will be overridden if installed libraries' versions dictate; for
+instance, if L<Math::BigInt> is at version > 1.999806, then the version
+of Perl will be overridden as though it is 5.26.
+
 =head2 run_command
 
   $self->run_command($command)
@@ -489,7 +518,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2017, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2019, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
